@@ -1,6 +1,7 @@
 import pickle
 import threading
 import time
+import traceback
 from datetime import timedelta
 from functools import partial, update_wrapper, wraps
 from queue import Empty, Full, PriorityQueue
@@ -249,6 +250,7 @@ class dispatch(LoggerMixin, threading.local):
         self.logger.debug('Dispatching subtasks: %r, options: %r', tasks, options)
 
     def _stash_subtask_results(self, progress_manager, stash_finished, tasks, **options):
+        self._backend.delete(self._dispatch_key)
         for results in gen_chunk(self._apply_tasks(tasks, **options), self._batch_size):
             self.logger.debug('%s tasks have been applied', len(results))
             progress_manager.update_progress_total(len(results))
@@ -326,6 +328,7 @@ class dispatch(LoggerMixin, threading.local):
                         result_queue.put((priority + 10, result))
                 except Exception as err:
                     self.logger.error('Subtask raised exception, task_id: %s', result.task_id)
+                    self.logger.error(traceback.format_exc())
                     if self._failure_on_subtask_exception:
                         raise err
 
